@@ -28,7 +28,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
+#include "config.h"
 #include "gdkconfig.h"
 
 #include "gtklayout.h"
@@ -59,7 +59,6 @@ enum {
   CHILD_PROP_Y
 };
 
-static void gtk_layout_class_init         (GtkLayoutClass *class);
 static void gtk_layout_get_property       (GObject        *object,
                                            guint           prop_id,
                                            GValue         *value,
@@ -71,7 +70,6 @@ static void gtk_layout_set_property       (GObject        *object,
 static GObject *gtk_layout_constructor    (GType                  type,
 					   guint                  n_properties,
 					   GObjectConstructParam *properties);
-static void gtk_layout_init               (GtkLayout      *layout);
 static void gtk_layout_finalize           (GObject        *object);
 static void gtk_layout_realize            (GtkWidget      *widget);
 static void gtk_layout_unrealize          (GtkWidget      *widget);
@@ -114,14 +112,14 @@ static void gtk_layout_set_adjustment_upper (GtkAdjustment *adj,
 					     gdouble        upper,
 					     gboolean       always_emit_changed);
 
-static GtkWidgetClass *parent_class = NULL;
+G_DEFINE_TYPE (GtkLayout, gtk_layout, GTK_TYPE_CONTAINER)
 
 /* Public interface
  */
 /**
  * gtk_layout_new:
- * @hadjustment: horizontal scroll adjustment, or %NULL
- * @vadjustment: vertical scroll adjustment, or %NULL
+ * @hadjustment: (allow-none): horizontal scroll adjustment, or %NULL
+ * @vadjustment: (allow-none): vertical scroll adjustment, or %NULL
  * 
  * Creates a new #GtkLayout. Unless you have a specific adjustment
  * you'd like the layout to use for scrolling, pass %NULL for
@@ -144,6 +142,24 @@ gtk_layout_new (GtkAdjustment *hadjustment,
   return GTK_WIDGET (layout);
 }
 
+/**
+ * gtk_layout_get_bin_window:
+ * @layout: a #GtkLayout
+ * 
+ * Retrieve the bin window of the layout used for drawing operations.
+ * 
+ * Return value: a #GdkWindow
+ *
+ * Since: 2.14
+ **/
+GdkWindow*
+gtk_layout_get_bin_window (GtkLayout *layout)
+{
+  g_return_val_if_fail (GTK_IS_LAYOUT (layout), NULL);
+
+  return layout->bin_window;
+}
+
 /**
  * gtk_layout_get_hadjustment:
  * @layout: a #GtkLayout
@@ -228,11 +244,10 @@ gtk_layout_set_adjustments (GtkLayout     *layout,
   if (layout->hadjustment != hadj)
     {
       layout->hadjustment = hadj;
-      g_object_ref (layout->hadjustment);
-      gtk_object_sink (GTK_OBJECT (layout->hadjustment));
+      g_object_ref_sink (layout->hadjustment);
       gtk_layout_set_adjustment_upper (layout->hadjustment, layout->width, FALSE);
       
-      g_signal_connect (layout->hadjustment, "value_changed",
+      g_signal_connect (layout->hadjustment, "value-changed",
 			G_CALLBACK (gtk_layout_adjustment_changed),
 			layout);
       need_adjust = TRUE;
@@ -241,11 +256,10 @@ gtk_layout_set_adjustments (GtkLayout     *layout,
   if (layout->vadjustment != vadj)
     {
       layout->vadjustment = vadj;
-      g_object_ref (layout->vadjustment);
-      gtk_object_sink (GTK_OBJECT (layout->vadjustment));
+      g_object_ref_sink (layout->vadjustment);
       gtk_layout_set_adjustment_upper (layout->vadjustment, layout->height, FALSE);
       
-      g_signal_connect (layout->vadjustment, "value_changed",
+      g_signal_connect (layout->vadjustment, "value-changed",
 			G_CALLBACK (gtk_layout_adjustment_changed),
 			layout);
       need_adjust = TRUE;
@@ -265,13 +279,13 @@ gtk_layout_finalize (GObject *object)
   g_object_unref (layout->hadjustment);
   g_object_unref (layout->vadjustment);
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (gtk_layout_parent_class)->finalize (object);
 }
 
 /**
  * gtk_layout_set_hadjustment:
  * @layout: a #GtkLayout
- * @adjustment: new scroll adjustment
+ * @adjustment: (allow-none): new scroll adjustment
  *
  * Sets the horizontal scroll adjustment for the layout.
  *
@@ -291,7 +305,7 @@ gtk_layout_set_hadjustment (GtkLayout     *layout,
 /**
  * gtk_layout_set_vadjustment:
  * @layout: a #GtkLayout
- * @adjustment: new scroll adjustment
+ * @adjustment: (allow-none): new scroll adjustment
  *
  * Sets the vertical scroll adjustment for the layout.
  *
@@ -359,7 +373,7 @@ gtk_layout_put (GtkLayout     *layout,
 
   layout->children = g_list_append (layout->children, child);
   
-  if (GTK_WIDGET_REALIZED (layout))
+  if (gtk_widget_get_realized (GTK_WIDGET (layout)))
     gtk_widget_set_parent_window (child->widget, layout->bin_window);
 
   gtk_widget_set_parent (child_widget, GTK_WIDGET (layout));
@@ -374,11 +388,7 @@ gtk_layout_move_internal (GtkLayout       *layout,
                           gint             y)
 {
   GtkLayoutChild *child;
-  
-  g_return_if_fail (GTK_IS_LAYOUT (layout));
-  g_return_if_fail (GTK_IS_WIDGET (widget));
-  g_return_if_fail (widget->parent == GTK_WIDGET (layout));  
-  
+
   child = get_child (layout, widget);
 
   g_assert (child);
@@ -399,8 +409,9 @@ gtk_layout_move_internal (GtkLayout       *layout,
 
   gtk_widget_thaw_child_notify (widget);
   
-  if (GTK_WIDGET_VISIBLE (widget) && GTK_WIDGET_VISIBLE (layout))
-    gtk_widget_queue_resize (GTK_WIDGET (widget));
+  if (gtk_widget_get_visible (widget) &&
+      gtk_widget_get_visible (GTK_WIDGET (layout)))
+    gtk_widget_queue_resize (widget);
 }
 
 /**
@@ -492,7 +503,7 @@ gtk_layout_set_size (GtkLayout     *layout,
   if (layout->vadjustment)
     gtk_layout_set_adjustment_upper (layout->vadjustment, layout->height, FALSE);
 
-  if (GTK_WIDGET_REALIZED (layout))
+  if (gtk_widget_get_realized (widget))
     {
       width = MAX (width, widget->allocation.width);
       height = MAX (height, widget->allocation.height);
@@ -503,8 +514,8 @@ gtk_layout_set_size (GtkLayout     *layout,
 /**
  * gtk_layout_get_size:
  * @layout: a #GtkLayout
- * @width: location to store the width set on @layout, or %NULL
- * @height: location to store the height set on @layout, or %NULL
+ * @width: (allow-none): location to store the width set on @layout, or %NULL
+ * @height: (allow-none): location to store the height set on @layout, or %NULL
  *
  * Gets the size that has been set on the layout, and that determines
  * the total extents of the layout's scrollbar area. See
@@ -561,33 +572,6 @@ gtk_layout_thaw (GtkLayout *layout)
 
 /* Basic Object handling procedures
  */
-GType
-gtk_layout_get_type (void)
-{
-  static GType layout_type = 0;
-
-  if (!layout_type)
-    {
-      static const GTypeInfo layout_info =
-      {
-	sizeof (GtkLayoutClass),
-	NULL,		/* base_init */
-	NULL,		/* base_finalize */
-	(GClassInitFunc) gtk_layout_class_init,
-	NULL,		/* class_finalize */
-	NULL,		/* class_data */
-	sizeof (GtkLayout),
-	0,		/* n_preallocs */
-	(GInstanceInitFunc) gtk_layout_init,
-      };
-
-      layout_type = g_type_register_static (GTK_TYPE_CONTAINER, "GtkLayout",
-					    &layout_info, 0);
-    }
-
-  return layout_type;
-}
-
 static void
 gtk_layout_class_init (GtkLayoutClass *class)
 {
@@ -599,8 +583,6 @@ gtk_layout_class_init (GtkLayoutClass *class)
   widget_class = (GtkWidgetClass*) class;
   container_class = (GtkContainerClass*) class;
 
-  parent_class = g_type_class_peek_parent (class);
-
   gobject_class->set_property = gtk_layout_set_property;
   gobject_class->get_property = gtk_layout_get_property;
   gobject_class->finalize = gtk_layout_finalize;
@@ -677,8 +659,17 @@ gtk_layout_class_init (GtkLayoutClass *class)
 
   class->set_scroll_adjustments = gtk_layout_set_adjustments;
 
+  /**
+   * GtkLayout::set-scroll-adjustments
+   * @horizontal: the horizontal #GtkAdjustment
+   * @vertical: the vertical #GtkAdjustment
+   *
+   * Set the scroll adjustments for the layout. Usually scrolled containers
+   * like #GtkScrolledWindow will emit this signal to connect two instances
+   * of #GtkScrollbar to the scroll directions of the #GtkLayout.
+   */
   widget_class->set_scroll_adjustments_signal =
-    g_signal_new ("set_scroll_adjustments",
+    g_signal_new (I_("set-scroll-adjustments"),
 		  G_OBJECT_CLASS_TYPE (gobject_class),
 		  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 		  G_STRUCT_OFFSET (GtkLayoutClass, set_scroll_adjustments),
@@ -830,9 +821,9 @@ gtk_layout_constructor (GType                  type,
   GObject *object;
   GtkAdjustment *hadj, *vadj;
   
-  object = G_OBJECT_CLASS (parent_class)->constructor (type,
-						       n_properties,
-						       properties);
+  object = G_OBJECT_CLASS (gtk_layout_parent_class)->constructor (type,
+								  n_properties,
+								  properties);
 
   layout = GTK_LAYOUT (object);
 
@@ -851,15 +842,12 @@ gtk_layout_constructor (GType                  type,
 static void 
 gtk_layout_realize (GtkWidget *widget)
 {
+  GtkLayout *layout = GTK_LAYOUT (widget);
   GList *tmp_list;
-  GtkLayout *layout;
   GdkWindowAttr attributes;
   gint attributes_mask;
 
-  g_return_if_fail (GTK_IS_LAYOUT (widget));
-
-  layout = GTK_LAYOUT (widget);
-  GTK_WIDGET_SET_FLAGS (layout, GTK_REALIZED);
+  gtk_widget_set_realized (widget, TRUE);
 
   attributes.window_type = GDK_WINDOW_CHILD;
   attributes.x = widget->allocation.x;
@@ -875,6 +863,7 @@ gtk_layout_realize (GtkWidget *widget)
 
   widget->window = gdk_window_new (gtk_widget_get_parent_window (widget),
 				   &attributes, attributes_mask);
+  gdk_window_set_back_pixmap (widget->window, NULL, FALSE);
   gdk_window_set_user_data (widget->window, widget);
 
   attributes.x = - layout->hadjustment->value,
@@ -889,7 +878,6 @@ gtk_layout_realize (GtkWidget *widget)
   gdk_window_set_user_data (layout->bin_window, widget);
 
   widget->style = gtk_style_attach (widget->style, widget->window);
-  gtk_style_set_background (widget->style, widget->window, GTK_STATE_NORMAL);
   gtk_style_set_background (widget->style, layout->bin_window, GTK_STATE_NORMAL);
 
   tmp_list = layout->children;
@@ -903,28 +891,24 @@ gtk_layout_realize (GtkWidget *widget)
 }
 
 static void
-gtk_layout_style_set (GtkWidget *widget, GtkStyle *old_style)
+gtk_layout_style_set (GtkWidget *widget,
+                      GtkStyle  *old_style)
 {
-  if (GTK_WIDGET_CLASS (parent_class)->style_set)
-    (* GTK_WIDGET_CLASS (parent_class)->style_set) (widget, old_style);
+  GTK_WIDGET_CLASS (gtk_layout_parent_class)->style_set (widget, old_style);
 
-  if (GTK_WIDGET_REALIZED (widget))
+  if (gtk_widget_get_realized (widget))
     {
       gtk_style_set_background (widget->style, GTK_LAYOUT (widget)->bin_window, GTK_STATE_NORMAL);
     }
 }
 
-static void 
+static void
 gtk_layout_map (GtkWidget *widget)
 {
+  GtkLayout *layout = GTK_LAYOUT (widget);
   GList *tmp_list;
-  GtkLayout *layout;
 
-  g_return_if_fail (GTK_IS_LAYOUT (widget));
-
-  layout = GTK_LAYOUT (widget);
-
-  GTK_WIDGET_SET_FLAGS (widget, GTK_MAPPED);
+  gtk_widget_set_mapped (widget, TRUE);
 
   tmp_list = layout->children;
   while (tmp_list)
@@ -932,9 +916,9 @@ gtk_layout_map (GtkWidget *widget)
       GtkLayoutChild *child = tmp_list->data;
       tmp_list = tmp_list->next;
 
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
-	  if (!GTK_WIDGET_MAPPED (child->widget))
+	  if (!gtk_widget_get_mapped (child->widget))
 	    gtk_widget_map (child->widget);
 	}
     }
@@ -946,30 +930,21 @@ gtk_layout_map (GtkWidget *widget)
 static void 
 gtk_layout_unrealize (GtkWidget *widget)
 {
-  GtkLayout *layout;
-
-  g_return_if_fail (GTK_IS_LAYOUT (widget));
-
-  layout = GTK_LAYOUT (widget);
+  GtkLayout *layout = GTK_LAYOUT (widget);
 
   gdk_window_set_user_data (layout->bin_window, NULL);
   gdk_window_destroy (layout->bin_window);
   layout->bin_window = NULL;
 
-  if (GTK_WIDGET_CLASS (parent_class)->unrealize)
-    (* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
+  GTK_WIDGET_CLASS (gtk_layout_parent_class)->unrealize (widget);
 }
 
 static void     
 gtk_layout_size_request (GtkWidget     *widget,
 			 GtkRequisition *requisition)
 {
+  GtkLayout *layout = GTK_LAYOUT (widget);
   GList *tmp_list;
-  GtkLayout *layout;
-
-  g_return_if_fail (GTK_IS_LAYOUT (widget));
-
-  layout = GTK_LAYOUT (widget);
 
   requisition->width = 0;
   requisition->height = 0;
@@ -991,14 +966,10 @@ static void
 gtk_layout_size_allocate (GtkWidget     *widget,
 			  GtkAllocation *allocation)
 {
+  GtkLayout *layout = GTK_LAYOUT (widget);
   GList *tmp_list;
-  GtkLayout *layout;
-
-  g_return_if_fail (GTK_IS_LAYOUT (widget));
 
   widget->allocation = *allocation;
-  
-  layout = GTK_LAYOUT (widget);
 
   tmp_list = layout->children;
 
@@ -1010,7 +981,7 @@ gtk_layout_size_allocate (GtkWidget     *widget,
       gtk_layout_allocate_child (layout, child);
     }
 
-  if (GTK_WIDGET_REALIZED (widget))
+  if (gtk_widget_get_realized (widget))
     {
       gdk_window_move_resize (widget->window,
 			      allocation->x, allocation->y,
@@ -1035,18 +1006,15 @@ gtk_layout_size_allocate (GtkWidget     *widget,
 }
 
 static gint 
-gtk_layout_expose (GtkWidget *widget, GdkEventExpose *event)
+gtk_layout_expose (GtkWidget      *widget,
+                   GdkEventExpose *event)
 {
-  GtkLayout *layout;
-
-  g_return_val_if_fail (GTK_IS_LAYOUT (widget), FALSE);
-
-  layout = GTK_LAYOUT (widget);
+  GtkLayout *layout = GTK_LAYOUT (widget);
 
   if (event->window != layout->bin_window)
     return FALSE;
-  
-  (* GTK_WIDGET_CLASS (parent_class)->expose_event) (widget, event);
+
+  GTK_WIDGET_CLASS (gtk_layout_parent_class)->expose_event (widget, event);
 
   return FALSE;
 }
@@ -1064,13 +1032,9 @@ static void
 gtk_layout_remove (GtkContainer *container, 
 		   GtkWidget    *widget)
 {
+  GtkLayout *layout = GTK_LAYOUT (container);
   GList *tmp_list;
-  GtkLayout *layout;
   GtkLayoutChild *child = NULL;
-  
-  g_return_if_fail (GTK_IS_LAYOUT (container));
-  
-  layout = GTK_LAYOUT (container);
 
   tmp_list = layout->children;
   while (tmp_list)
@@ -1097,15 +1061,10 @@ gtk_layout_forall (GtkContainer *container,
 		   GtkCallback   callback,
 		   gpointer      callback_data)
 {
-  GtkLayout *layout;
+  GtkLayout *layout = GTK_LAYOUT (container);
   GtkLayoutChild *child;
   GList *tmp_list;
 
-  g_return_if_fail (GTK_IS_LAYOUT (container));
-  g_return_if_fail (callback != NULL);
-
-  layout = GTK_LAYOUT (container);
-
   tmp_list = layout->children;
   while (tmp_list)
     {
@@ -1141,14 +1100,10 @@ static void
 gtk_layout_adjustment_changed (GtkAdjustment *adjustment,
 			       GtkLayout     *layout)
 {
-  GtkWidget *widget;
-
-  widget = GTK_WIDGET (layout);
-
   if (layout->freeze_count)
     return;
 
-  if (GTK_WIDGET_REALIZED (layout))
+  if (gtk_widget_get_realized (GTK_WIDGET (layout)))
     {
       gdk_window_move (layout->bin_window,
 		       - layout->hadjustment->value,
