@@ -1,13 +1,25 @@
-/* Menus
+/* testmenus.c -- dynamically add and remove items to a menu 
+ * Copyright (C) 2002  Red Hat, Inc.
+ * Author: Owen Taylor
  *
- * This program dynamically adds and removes items to a menu to test that
- * scroll arrows operate correctly.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * Written by Owen Taylor <otaylor@redhat.com>
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #undef GTK_DISABLE_DEPRECATED
-#include <config.h>
+#include "config.h"
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -139,7 +151,7 @@ main (int argc, char **argv)
       gtk_menu_shell_append (GTK_MENU_SHELL (menubar), menuitem);
       gtk_widget_show (menuitem);
       
-      g_timeout_add (250, change_item, submenu);
+      gdk_threads_add_timeout (250, change_item, submenu);
 
       menuitem = gtk_menu_item_new_with_label ("bar");
       gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), create_menu (4, TRUE));
@@ -212,12 +224,12 @@ main (int argc, char **argv)
       g_signal_connect_swapped (button, "clicked",
 				G_CALLBACK(gtk_widget_destroy), window);
       gtk_box_pack_start (GTK_BOX (box2), button, TRUE, TRUE, 0);
-      GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+      gtk_widget_set_can_default (button, TRUE);
       gtk_widget_grab_default (button);
       gtk_widget_show (button);
     }
 
-  if (!GTK_WIDGET_VISIBLE (window))
+  if (!gtk_widget_get_visible (window))
     {
       gtk_widget_show (window);
     }
